function [x_h,x_p] = HPSS(x,N,H,w,fs,lh_sec,lp_Hz)
% x:      Input signal
% N:      Frame length
% H:      Hopsize
% w:      Window function of length N
% fs:     Sampling rate of x
% lh_sec: Horizontal median filter length given in seconds
% lp_Hz:  Percussive median filter length given in Hertz

%% stft

%% power spectrogram

%% median filtering

%% masking

%% istft

end